==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/gl.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galería",
    "Aborting preview. Could not find the file" : "Cancelando a vista previa. Non foi posíbel atopar o ficheiro",
    "Could not load the description" : "Non foi posíbel cargar a descrición",
    "Could not load the description: " : "Non foi posíbel cargar a descrición:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Non foi posíbel cargar o aviso de copyright:",
    "Copyright notice" : "Aviso de copyright",
    "Link to copyright document" : "Ligazón ao documento do copyright",
    "This application may not work properly on your browser." : "É probábel que esta aplicación non traballe axeitadamente no seu navegador.",
    "For an improved experience, please install one of the following alternatives" : "Para ter unha mellor experiencia, instale unha das seguintes alternativas",
    "Your browser is not supported!" : "O seu navegador non é compatíbel!",
    "please install one of the following alternatives" : "instale unha das seguintes alternativas",
    "Configuration error" : "Produciuse un erro de configuración",
    "New" : "Novo",
    "Error loading slideshow template" : "Produciuse un erro ao cargar o modelo do diaporama",
    "Next" : "Seguinte",
    "Play" : "Reproducir",
    "Pause" : "Pausa",
    "Previous" : "Anterior",
    "Close" : "Pechar",
    "Download" : "Descargar",
    "Toggle background" : "Alternar o fondo",
    "Delete" : "Eliminar",
    "\"{name}\" is an invalid file name." : "«{name}» é un nome incorrecto de ficheiro.",
    "File name cannot be empty." : "O nome de ficheiro non pode estar baleiro",
    "Upload" : "Enviar",
    "Error" : "Erro",
    "Error while sharing" : "Produciuse un erro ao compartir",
    "Error while unsharing" : "Produciuse un erro ao deixar de compartir",
    "Error while changing permissions" : "Produciuse un erro ao cambiar os permisos",
    "Shared with you and the group {group} by {owner}" : "Compartido con vostede e co grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido con vostede por {owner}",
    "Share with users or groups …" : "Compartir con usuarios ou grupos ...",
    "Share with users, groups or remote users …" : "Compartir con usuarios, grupos ou usuarios remotos ...",
    "Share" : "Compartir",
    "Share link" : "Ligazón para compartir",
    "The public link will expire no later than {days} days after it is created" : "A ligazón pública caducará, a máis tardar, {days} días após a súa creación",
    "Link" : "Ligazón",
    "Password protect" : "Protexido con contrasinal",
    "Password" : "Contrasinal",
    "Choose a password for the public link" : "Escolla un contrasinal para a ligazón pública",
    "Allow editing" : "Permitir a edición",
    "Email link to person" : "Enviar ligazón por correo",
    "Send" : "Enviar",
    "Set expiration date" : "Definir a data de caducidade",
    "Expiration" : "Caducidade",
    "Expiration date" : "Data de caducidade",
    "An error occured. Please try again" : "Produciuse un erro, ténteo de novo",
    "Adding user..." : "Engadindo usuario...",
    "group" : "grupo",
    "remote" : "remoto",
    "Resharing is not allowed" : "Non se permite volver compartir",
    "Unshare" : "Deixar de compartir",
    "notify by email" : "notificar por correo",
    "can share" : "pode compartir",
    "can edit" : "pode editar",
    "access control" : "control de acceso",
    "create" : "crear",
    "change" : "cambio",
    "delete" : "eliminar",
    "Password protected" : "Protexido con contrasinal",
    "Error unsetting expiration date" : "Produciuse un erro ao retirar a data de caducidade",
    "Error setting expiration date" : "Produciuse un erro ao definir a data de caducidade",
    "Sending ..." : "Enviando...",
    "Email sent" : "Correo enviado",
    "Warning" : "Aviso",
    "This share is password-protected" : "Esta compartición está protexida con contrasinal",
    "The password is wrong. Try again." : "O contrasinal é incorrecto. Ténteo de novo.",
    "Sort by date" : "Ordenar pola data",
    "Sort by name" : "Ordenar polo nome",
    "Cancel upload" : "Cancelar o envío",
    "Album information" : "Información do álbum",
    "File list" : "Lista de ficheiros",
    "Sorry, this file could not be found." : "Sentímolo, este ficheiro non foi atopado.",
    "Reasons might be:" : "As razóns poderían ser:",
    "the wrong file ID was provided" : "forneceu un ID de ficheiro estragado",
    "the file was removed" : "o ficheiro foi retirado",
    "the file is corrupt" : "o ficheiro está estragado",
    "the encryption key is missing" : "non se atopou a chave de cifrado",
    "Here is the error message returned by the server: " : "Esta é a mensaxe co que respondeu o servidor:",
    "Sorry, but the server could not fulfill your request." : "Sentímolo, o servidor non puido completar a súa solicitude",
    "Possible reasons for the problem:" : "Posíbeis causas deste problema:",
    "a conflicting app was installed" : "instalouse unha aplicación conflitiva",
    "a required component is missing or was disconnected" : "non se atopou ou desconectouse un compoñente requirido",
    "the filesystem is not readable" : "o sistema de ficheiros non é lexíbel.",
    "For more information, please contact your friendly ownCloud administrator." : "Para obter máis información, póñase en contacto co administrador do ownCloud.",
    "Sorry, this link doesn't seem to work anymore." : "Sentímolo, semella que esta ligazón non funciona.",
    "the item was removed" : "o elemento foi retirado",
    "the link has expired" : "caducou a ligazón",
    "sharing is disabled" : "foi desactivada a compartición",
    "For more information, please ask the person who has sent you this link." : "Para obter máis información, pregúntelle á persoa que lle enviou esta ligazón.",
    "Picture view" : "Ver imaxes"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/gl.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galería",
    "There was a problem reading files from this album" : "Produciuse un problema lendo os ficheiros deste álbum ",
    "Aborting preview. Could not find the file" : "Cancelando a vista previa. Non foi posíbel atopar o ficheiro",
    "Could not move \"{file}\", target exists" : "Non foi posíbel mover «{file}», o destino xa existe",
    "Could not move \"{file}\"" : "Non foi posíbel mover «{file}»",
    "No compatible server found at {remote}" : "Non se atopa un servidor compatíbel en {remote}",
    "Invalid server url" : "URL de servidor incorrecto",
    "Gallery view" : "Vista da galería",
    "Could not load the description" : "Non foi posíbel cargar a descrición",
    "Could not load the description: " : "Non foi posíbel cargar a descrición:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Non foi posíbel cargar o aviso de copyright:",
    "Copyright notice" : "Aviso de copyright",
    "Link to copyright document" : "Ligazón ao documento do copyright",
    "This application may not work properly on your browser." : "É probábel que esta aplicación non traballe axeitadamente no seu navegador.",
    "For an improved experience, please install one of the following alternatives" : "Para ter unha mellor experiencia, instale unha das seguintes alternativas",
    "Your browser is not supported!" : "O seu navegador non é compatíbel!",
    "please install one of the following alternatives" : "instale unha das seguintes alternativas",
    "Album cannot be shown" : "O álbum non pode ser amosado",
    "No media files found" : "Non se atopan ficheiros multimedia",
    "Upload pictures in the files app to display them here" : "Engadir fotos nos ficheiros da aplicación para amosalos aquí",
    "Upload new files via drag and drop or by using the [+] button above" : "Engadir ficheiros novos arrastrando e soltando ou co botón [+] de enriba",
    "Configuration error" : "Produciuse un erro de configuración",
    "New" : "Novo",
    "Hide Album" : "Agochar o álbum",
    "Could not hide album" : "Non foi posíbel agochar o álbum",
    "Error loading slideshow template" : "Produciuse un erro ao cargar o modelo do diaporama",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Erro!</strong> Non foi posíbel xerar unha vista previa deste ficheiro.<br>vaia á seguinte diapositiva mentres se elimina esta imaxe do diaporama.",
    "Next" : "Seguinte",
    "Play" : "Reproducir",
    "Pause" : "Pausa",
    "Previous" : "Anterior",
    "Close" : "Pechar",
    "Download" : "Descargar",
    "Toggle background" : "Alternar o fondo",
    "Delete" : "Eliminar",
    "Could not create file \"{file}\" because it already exists" : "Non foi posíbel crear o ficheiro «{file}» por mor de que xa existe",
    "Could not create file \"{file}\"" : "Non foi posíbel crear o ficheiro «{file}»",
    "\"{name}\" is an invalid file name." : "«{name}» é un nome incorrecto de ficheiro.",
    "File name cannot be empty." : "O nome de ficheiro non pode estar baleiro",
    "\"{name}\" is not an allowed filetype" : "«{name}» non é un tipo de ficheiro permitido",
    "Upload" : "Enviar",
    "Error" : "Erro",
    "Error while sharing" : "Produciuse un erro ao compartir",
    "Error while unsharing" : "Produciuse un erro ao deixar de compartir",
    "Error while changing permissions" : "Produciuse un erro ao cambiar os permisos",
    "Shared with you and the group {group} by {owner}" : "Compartido con vostede e co grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido con vostede por {owner}",
    "Share with users or groups …" : "Compartir con usuarios ou grupos ...",
    "Share with users, groups or remote users …" : "Compartir con usuarios, grupos ou usuarios remotos ...",
    "Share" : "Compartir",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Comparta con persoas noutros servidores empregando o seu ID de nube federada nomeusuario@exemplo.com/cloud",
    "Share link" : "Compartir ligazón",
    "The public link will expire no later than {days} days after it is created" : "A ligazón pública caducará, a máis tardar, {days} días após a súa creación",
    "Link" : "Ligazón",
    "Password protect" : "Protexido con contrasinal",
    "Password" : "Contrasinal",
    "Choose a password for the public link" : "Escolla un contrasinal para a ligazón pública",
    "Allow editing" : "Permitir a edición",
    "Email link to person" : "Enviar ligazón por correo",
    "Send" : "Enviar",
    "Set expiration date" : "Definir a data de caducidade",
    "Expiration" : "Caducidade",
    "Expiration date" : "Data de caducidade",
    "This list is maybe truncated - please refine your search term to see more results." : "É probábel que esta lista estea truncada, afine o termo de busca para ver máis resultados.",
    "No users or groups found for {search}" : "Non se atoparon usuarios ou grupos para {search}",
    "No users found for {search}" : "Non se atoparon usuarios para {search}",
    "An error occured. Please try again" : "Produciuse un erro, ténteo de novo",
    "Adding user..." : "Engadindo usuario...",
    "group" : "grupo",
    "remote" : "remoto",
    "Resharing is not allowed" : "Non se permite volver compartir",
    "Error while retrieving shares" : "Produciuse un erro ao recuperar compartidos",
    "Unshare" : "Deixar de compartir",
    "notify by email" : "notificar por correo",
    "can share" : "pode compartir",
    "can edit" : "pode editar",
    "access control" : "control de acceso",
    "create" : "crear",
    "change" : "cambio",
    "delete" : "eliminar",
    "Password protected" : "Protexido con contrasinal",
    "Error unsetting expiration date" : "Produciuse un erro ao retirar a data de caducidade",
    "Error setting expiration date" : "Produciuse un erro ao definir a data de caducidade",
    "Sending ..." : "Enviando...",
    "Email sent" : "Correo enviado",
    "Warning" : "Aviso",
    "This share is password-protected" : "Esta compartición está protexida con contrasinal",
    "The password is wrong. Try again." : "O contrasinal é incorrecto. Ténteo de novo.",
    "Sort by date" : "Ordenar pola data",
    "Sort by name" : "Ordenar polo nome",
    "Cancel upload" : "Cancelar o envío",
    "Album information" : "Información do álbum",
    "File list" : "Lista de ficheiros",
    "Sorry, this file could not be found." : "Sentímolo, este ficheiro non foi atopado.",
    "Reasons might be:" : "As razóns poderían ser:",
    "the wrong file ID was provided" : "forneceu un ID de ficheiro estragado",
    "the file was removed" : "o ficheiro foi retirado",
    "the file is corrupt" : "o ficheiro está estragado",
    "the encryption key is missing" : "non se atopou a chave de cifrado",
    "Here is the error message returned by the server: " : "Esta é a mensaxe co que respondeu o servidor:",
    "For more information, please contact your friendly Nextcloud administrator." : "Para obter máis información, póñase en contacto co administrador do Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "Sentímolo, o servidor non puido completar a súa solicitude",
    "Possible reasons for the problem:" : "Posíbeis causas deste problema:",
    "a conflicting app was installed" : "instalouse unha aplicación conflitiva",
    "a required component is missing or was disconnected" : "non se atopou ou desconectouse un compoñente requirido",
    "the filesystem is not readable" : "o sistema de ficheiros non é lexíbel.",
    "For more information, please contact your friendly ownCloud administrator." : "Para obter máis información, póñase en contacto co administrador do ownCloud.",
    "Sorry, this link doesn't seem to work anymore." : "Sentímolo, semella que esta ligazón non funciona.",
    "the item was removed" : "o elemento foi retirado",
    "the link has expired" : "caducou a ligazón",
    "sharing is disabled" : "foi desactivada a compartición",
    "For more information, please ask the person who has sent you this link." : "Para obter máis información, pregúntelle á persoa que lle enviou esta ligazón.",
    "Add to your Nextcloud" : "Engadir ao seu Nextcloud",
    "Picture view" : "Ver imaxes"
},
"nplurals=2; plural=(n != 1);");
